#############################################################################
#
# MODULE:   	Grass Compilation
# AUTHOR(S):	Original author unknown - probably CERL
#		Markus Neteler - Germany/Italy - neteler@itc.it
#   	    	Justin Hickey - Thailand - jhickey@hpcc.nectec.or.th
#   	    	Huidae Cho - Korea - grass4u@gmail.com
#   	    	Eric G. Miller - egm2@jps.net
# PURPOSE:  	The source file for this Makefile is in src/CMD/head/head.in.
#		It is the top part of a file called make.rules which is used
#		for compiling all GRASS modules. This part of the file provides
#		make variables that are dependent on the results of the
#		configure script.
# COPYRIGHT:    (C) 2000 by the GRASS Development Team
#
#               This program is free software under the GNU General Public
#   	    	License (>=v2). Read the file COPYING that comes with GRASS
#   	    	for details.
#
#############################################################################

############################## Make Variables ###############################

CC                  = /usr/bin/clang
CXX                 = /usr/bin/clang++
LEX                 = flex
YACC                = bison -y
PERL                = /usr/bin/perl
AR                  = ar
RANLIB              = ranlib
MKDIR               = mkdir -p
CHMOD               = chmod
INSTALL             = /usr/local/opt/coreutils/bin/ginstall -c 
INSTALL_DATA        = ${INSTALL} -m 644

prefix              = /opt/QGIS/qgis-deps-0.2.2/stage
exec_prefix         = /opt/QGIS/qgis-deps-0.2.2/stage
ARCH                = x86_64-apple-darwin19.3.0
UNIX_BIN            = ${exec_prefix}/bin
INST_DIR            = ${prefix}/grass78

GRASS_HOME          = /opt/QGIS/qgis-deps-0.2.2/stage/grass78
RUN_GISBASE         = /opt/QGIS/qgis-deps-0.2.2/stage/grass78

GRASS_VERSION_MAJOR = 7
GRASS_VERSION_MINOR = 8
GRASS_VERSION_RELEASE = 2
GRASS_VERSION_DATE  = 2019
GRASS_VERSION_GIT   = exported

STRIPFLAG           = 
LD_SEARCH_FLAGS     = 
LD_LIBRARY_PATH_VAR = DYLD_LIBRARY_PATH

#generate static (ST) or shared (SH)
GRASS_LIBRARY_TYPE  = shlib

#static libs:
STLIB_LD            = ${AR} cr
STLIB_PREFIX        = lib
STLIB_SUFFIX        = .a

#shared libs
SHLIB_PREFIX        = lib
SHLIB_LD            = clang -dynamiclib -compatibility_version ${GRASS_VERSION_MAJOR}.${GRASS_VERSION_MINOR} -current_version ${GRASS_VERSION_MAJOR}.${GRASS_VERSION_MINOR} -install_name ${INST_DIR}/lib/lib${LIB_NAME}${SHLIB_SUFFIX}
SHLIB_LDFLAGS       = 
SHLIB_CFLAGS        = -fno-common
SHLIB_SUFFIX        = .dylib
EXE                 = 

DEFAULT_DATABASE    =
DEFAULT_LOCATION    =

CPPFLAGS            =   -I/opt/QGIS/qgis-deps-0.2.2/stage/include
CFLAGS              = -O2 
CXXFLAGS            = -O2
INCLUDE_DIRS        =  -I/opt/QGIS/qgis-deps-0.2.2/stage/include
LINK_FLAGS          =    -L/opt/QGIS/qgis-deps-0.2.2/stage/lib

DLLIB               = 
XCFLAGS             = 
XLIBPATH            = 
XLIB                =  
XEXTRALIBS          = 
USE_X11             = 

MATHLIB             =  
ICONVLIB            = -liconv
INTLLIB             = 
SOCKLIB             = 

#ZLIB:
ZLIB                =  -lz 
ZLIBINCPATH         =  -I/opt/QGIS/qgis-deps-0.2.2/stage/include
ZLIBLIBPATH         =  -L/opt/QGIS/qgis-deps-0.2.2/stage/lib

#BZIP2:
BZIP2LIB            = 
BZIP2INCPATH        = 
BZIP2LIBPATH        = 

#ZSTD:
ZSTDLIB             =  -lzstd 
ZSTDINCPATH         =  -I/opt/QGIS/qgis-deps-0.2.2/stage/include
ZSTDLIBPATH         =  -L/opt/QGIS/qgis-deps-0.2.2/stage/lib

DBMIEXTRALIB        = 

#readline
READLINEINCPATH     = 
READLINELIBPATH     = 
READLINELIB         = 
HISTORYLIB          = 

#PostgreSQL:
PQINCPATH           = 
PQLIBPATH           = 
PQLIB               = 
USE_POSTGRES        = 

#MySQL:
MYSQLINCPATH        = 
MYSQLLIBPATH        = 
MYSQLLIB            = 
MYSQLDLIB           = 

#SQLite:
SQLITEINCPATH       =  -I/opt/QGIS/qgis-deps-0.2.2/stage/include
SQLITELIBPATH       =  -L/opt/QGIS/qgis-deps-0.2.2/stage/lib
SQLITELIB           =  -lsqlite3 

#ODBC:
ODBCINC             = 
ODBCLIB             = 

#Image formats:
PNGINC              =  -I/opt/QGIS/qgis-deps-0.2.2/stage/include
PNGLIB              =  -L/opt/QGIS/qgis-deps-0.2.2/stage/lib -lpng  -lz  
USE_PNG             = 1

TIFFINCPATH         =  -I/opt/QGIS/qgis-deps-0.2.2/stage/include
TIFFLIBPATH         =  -L/opt/QGIS/qgis-deps-0.2.2/stage/lib
TIFFLIB             =  -ltiff 

#openGL files for NVIZ/r3.showdspf
OPENGLINC           = 
OPENGLLIB           = 
OPENGLULIB          = 
OPENGL_X11          = 
OPENGL_AQUA         = 
OPENGL_WINDOWS      = 
USE_OPENGL          = 

#FFTW:
FFTWINC             = 
FFTWLIB             = 

#LAPACK/BLAS stuff for gmath lib:
BLASLIB             = 
BLASINC             = 
LAPACKLIB           = 
LAPACKINC           = 

#GDAL/OGR
GDALLIBS            = -L/opt/QGIS/qgis-deps-0.2.2/stage/lib -lgdal
GDALCFLAGS          = -I/opt/QGIS/qgis-deps-0.2.2/stage/include
USE_GDAL            = 1
USE_OGR             = 1

#NetCDF
NETCDFLIBS          = -L/opt/QGIS/qgis-deps-0.2.2/stage/lib -lnetcdf
NETCDFCFLAGS        = -I/opt/QGIS/qgis-deps-0.2.2/stage/include    
USE_NETCDF          = 1

#LAS LiDAR through libLAS
LASLIBS             = 
LASCFLAGS           = 
LASINC              = 
USE_LIBLAS          = 

#LAS LiDAR through PDAL
PDALLIBS             = 
PDALCPPFLAGS         = 
PDALINC              = 
USE_PDAL             = 

#GEOS
GEOSLIBS            = -L/opt/QGIS/qgis-deps-0.2.2/stage/lib -lgeos_c -lgeos_c 
GEOSCFLAGS          = -I/opt/QGIS/qgis-deps-0.2.2/stage/include
USE_GEOS            = 1

#FreeType:
FTINC               = 
FTLIB               = 

#PROJ.4:
PROJINC             =  -I/opt/QGIS/qgis-deps-0.2.2/stage/include
PROJLIB             =  -L/opt/QGIS/qgis-deps-0.2.2/stage/lib -lproj 
PROJSHARE           = /opt/QGIS/qgis-deps-0.2.2/stage/share/proj

#OPENDWG:
OPENDWGINCPATH      = 
OPENDWGLIBPATH      = 
OPENDWGLIB          = 
USE_OPENDWG         = 

#cairo
CAIROINC                  = 
CAIROLIB                  = 
USE_CAIRO                 = 
CAIRO_HAS_XRENDER         = 
CAIRO_HAS_XRENDER_SURFACE = 

#Python
PYTHON              = python3

#regex
REGEXINCPATH        = 
REGEXLIBPATH        = 
REGEXLIB            =  
USE_REGEX           = 1

#pthreads
PTHREADINCPATH      =  -I/opt/QGIS/qgis-deps-0.2.2/stage/include/boost/thread
PTHREADLIBPATH      =  -L/opt/QGIS/qgis-deps-0.2.2/stage/lib
PTHREADLIB          =  
USE_PTHREAD         = 1

#OpenMP
OMPINCPATH          = 
OMPLIBPATH          = 
OMPLIB              = 
OMPCFLAGS           = 
USE_OPENMP          = 

#OpenCL
OCLINCPATH          = 
OCLLIBPATH          = 
OCLLIB              = 
USE_OPENCL          = 

#i18N
HAVE_NLS            = 

#Large File Support (LFS)
USE_LARGEFILES      = 1
LFS_CFLAGS          = 

#BSD sockets
HAVE_SOCKET         = 1

MINGW		    = 
MACOSX_APP	    = 
MACOSX_ARCHS        = 
MACOSX_SDK          = 

# Cross compilation
CROSS_COMPILING     =  
